# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/kendrick',
                'doc_host': 'https://fligt.github.io',
                'git_url': 'https://github.com/fligt/kendrick',
                'lib_path': 'kendrick'},
  'syms': { 'kendrick.centroid': {'kendrick.centroid.centralize': ('centroiding-again.html#centralize', 'kendrick/centroid.py')},
            'kendrick.explore': { 'kendrick.explore.get_time_averaged_centroids': ( 'exploring.html#get_time_averaged_centroids',
                                                                                    'kendrick/explore.py'),
                                  'kendrick.explore.histogram': ('exploring.html#histogram', 'kendrick/explore.py'),
                                  'kendrick.explore.interactive_plot': ('exploring.html#interactive_plot', 'kendrick/explore.py'),
                                  'kendrick.explore.read_mzml': ('exploring.html#read_mzml', 'kendrick/explore.py'),
                                  'kendrick.explore.read_raw': ('exploring.html#read_raw', 'kendrick/explore.py')}}}
